# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_url.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19gcp/gcp_compute_url.proto\x12\x1boak9.tython.gcp.compute_url\x1a\x13shared/shared.proto\"\xe6\x01\n+ComputeUrlMapXDefaultRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"f\n;ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"h\nFComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xcb\x01\n;ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12x\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\x89\x02\n5ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy\x12g\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXAbort\x12g\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicyXDelay\"O\n4ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"\\\n:ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xcf\x01\n,ComputeUrlMapXDefaultRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12p\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRetryPolicyXPerTryTimeout\"J\n(ComputeUrlMapXDefaultRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"`\n+ComputeUrlMapXDefaultRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\x97\x01\nYComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x98\x01\nZComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xc2\x03\nEComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\x96\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32v.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x98\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32w.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xde\x01\n8ComputeUrlMapXDefaultRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12y\n\rheader_action\x18\x03 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServicesXHeaderAction\"\xf9\x05\n ComputeUrlMapXDefaultRouteAction\x12]\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32H.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXCorsPolicy\x12r\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32R.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXFaultInjectionPolicy\x12p\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRequestMirrorPolicy\x12_\n\x0cretry_policy\x18\x04 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXRetryPolicy\x12V\n\x07timeout\x18\x05 \x01(\x0b\x32\x45.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXTimeout\x12]\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32H.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXUrlRewrite\x12x\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteActionXWeightedBackendServices\"\xb6\x01\n ComputeUrlMapXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"l\n.ComputeUrlMapXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"m\n/ComputeUrlMapXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xbf\x02\n\x1a\x43omputeUrlMapXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12k\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderActionXRequestHeadersToAdd\x12m\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32L.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderActionXResponseHeadersToAdd\"R\n\x16\x43omputeUrlMapXHostRule\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\x14\n\x0cpath_matcher\x18\x03 \x01(\t\"\xf2\x01\n7ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"r\nGComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"t\nRComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe4\x01\nGComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x84\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32o.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xad\x02\nAComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy\x12s\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32\x64.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXAbort\x12s\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x64.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicyXDelay\"[\n@ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"h\nFComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe7\x01\n8ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12|\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicyXPerTryTimeout\"V\n4ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"l\n7ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa3\x01\neComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa4\x01\nfComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xe8\x03\nQComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa3\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x82\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa5\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x83\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xf7\x01\nDComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x85\x01\n\rheader_action\x18\x03 \x01(\x0b\x32n.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServicesXHeaderAction\"\xda\x06\n,ComputeUrlMapXPathMatcherXDefaultRouteAction\x12i\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXCorsPolicy\x12~\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32^.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXFaultInjectionPolicy\x12|\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32].oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRequestMirrorPolicy\x12k\n\x0cretry_policy\x18\x04 \x01(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXRetryPolicy\x12\x62\n\x07timeout\x18\x05 \x01(\x0b\x32Q.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXTimeout\x12i\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32T.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXUrlRewrite\x12\x84\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x61.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteActionXWeightedBackendServices\"\xc2\x01\n,ComputeUrlMapXPathMatcherXDefaultUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"x\n:ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"y\n;ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xe3\x02\n&ComputeUrlMapXPathMatcherXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12w\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderActionXRequestHeadersToAdd\x12y\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderActionXResponseHeadersToAdd\"\xf4\x01\n9ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"t\nIComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"v\nTComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xe8\x01\nIComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x86\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32q.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xb3\x02\nCComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12u\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXAbort\x12u\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32\x66.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicyXDelay\"]\nBComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"j\nHComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xeb\x01\n:ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12~\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicyXPerTryTimeout\"X\n6ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"n\n9ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa5\x01\ngComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa6\x01\nhComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xee\x03\nSComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa5\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x84\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa7\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x85\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xfb\x01\nFComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x87\x01\n\rheader_action\x18\x03 \x01(\x0b\x32p.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServicesXHeaderAction\"\xeb\x06\n.ComputeUrlMapXPathMatcherXPathRuleXRouteAction\x12k\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32V.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXCorsPolicy\x12\x80\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXFaultInjectionPolicy\x12~\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32_.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRequestMirrorPolicy\x12m\n\x0cretry_policy\x18\x04 \x01(\x0b\x32W.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXRetryPolicy\x12\x64\n\x07timeout\x18\x05 \x01(\x0b\x32S.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXTimeout\x12k\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32V.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXUrlRewrite\x12\x86\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteActionXWeightedBackendServices\"\xc4\x01\n.ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\x8a\x02\n\"ComputeUrlMapXPathMatcherXPathRule\x12\r\n\x05paths\x18\x01 \x03(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x61\n\x0croute_action\x18\x03 \x01(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXRouteAction\x12\x61\n\x0curl_redirect\x18\x04 \x01(\x0b\x32K.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRuleXUrlRedirect\"\x83\x01\nEComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x84\x01\nFComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\x86\x03\n1ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\x82\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXRequestHeadersToAdd\x12\x84\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x63.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderActionXResponseHeadersToAdd\"r\nHComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\x12\x11\n\trange_end\x18\x01 \x01(\x01\x12\x13\n\x0brange_start\x18\x02 \x01(\x01\"\xd3\x02\n=ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x13\n\x0bheader_name\x18\x02 \x01(\t\x12\x14\n\x0cinvert_match\x18\x03 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x04 \x01(\t\x12\x15\n\rpresent_match\x18\x05 \x01(\x08\x12\x13\n\x0bregex_match\x18\x06 \x01(\t\x12\x14\n\x0csuffix_match\x18\x07 \x01(\t\x12z\n\x0brange_match\x18\x08 \x01(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatchesXRangeMatch\"k\nLComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xe3\x01\n?ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x1d\n\x15\x66ilter_match_criteria\x18\x01 \x01(\t\x12\x80\x01\n\rfilter_labels\x18\x02 \x03(\x0b\x32i.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFiltersXFilterLabels\"\x96\x01\nEComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\x12\x13\n\x0b\x65xact_match\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x15\n\rpresent_match\x18\x03 \x01(\x08\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\"\xfc\x03\n/ComputeUrlMapXPathMatcherXRouteRulesXMatchRules\x12\x17\n\x0f\x66ull_path_match\x18\x01 \x01(\t\x12\x13\n\x0bignore_case\x18\x02 \x01(\x08\x12\x14\n\x0cprefix_match\x18\x03 \x01(\t\x12\x13\n\x0bregex_match\x18\x04 \x01(\t\x12r\n\x0eheader_matches\x18\x05 \x03(\x0b\x32Z.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXHeaderMatches\x12v\n\x10metadata_filters\x18\x06 \x03(\x0b\x32\\.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXMetadataFilters\x12\x83\x01\n\x17query_parameter_matches\x18\x07 \x03(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRulesXQueryParameterMatches\"\xf6\x01\n;ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x15\n\rallow_headers\x18\x02 \x03(\t\x12\x15\n\rallow_methods\x18\x03 \x03(\t\x12\x1c\n\x14\x61llow_origin_regexes\x18\x04 \x03(\t\x12\x15\n\rallow_origins\x18\x05 \x03(\t\x12\x10\n\x08\x64isabled\x18\x06 \x01(\x08\x12\x16\n\x0e\x65xpose_headers\x18\x07 \x03(\t\x12\x0f\n\x07max_age\x18\x08 \x01(\x01\"v\nKComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12\x13\n\x0bhttp_status\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"x\nVComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xec\x01\nKComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\x12\x12\n\npercentage\x18\x01 \x01(\x01\x12\x88\x01\n\x0b\x66ixed_delay\x18\x02 \x01(\x0b\x32s.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelayXFixedDelay\"\xb9\x02\nEComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12w\n\x05\x61\x62ort\x18\x01 \x01(\x0b\x32h.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXAbort\x12w\n\x05\x64\x65lay\x18\x02 \x01(\x0b\x32h.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicyXDelay\"_\nDComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\"l\nJComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"\xf0\x01\n<ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12\x13\n\x0bnum_retries\x18\x01 \x01(\x01\x12\x18\n\x10retry_conditions\x18\x02 \x03(\t\x12\x80\x01\n\x0fper_try_timeout\x18\x03 \x01(\x0b\x32g.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicyXPerTryTimeout\"Z\n8ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12\r\n\x05nanos\x18\x01 \x01(\x01\x12\x0f\n\x07seconds\x18\x02 \x01(\t\"p\n;ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x14\n\x0chost_rewrite\x18\x01 \x01(\t\x12\x1b\n\x13path_prefix_rewrite\x18\x02 \x01(\t\"\xa7\x01\niComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xa8\x01\njComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\x12\x13\n\x0bheader_name\x18\x01 \x01(\t\x12\x14\n\x0cheader_value\x18\x02 \x01(\t\x12\x0f\n\x07replace\x18\x03 \x01(\x08\"\xf4\x03\nUComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\x12!\n\x19request_headers_to_remove\x18\x01 \x03(\t\x12\"\n\x1aresponse_headers_to_remove\x18\x02 \x03(\t\x12\xa7\x01\n\x16request_headers_to_add\x18\x03 \x03(\x0b\x32\x86\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXRequestHeadersToAdd\x12\xa9\x01\n\x17response_headers_to_add\x18\x04 \x03(\x0b\x32\x87\x01.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderActionXResponseHeadersToAdd\"\xff\x01\nHComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\x12\x17\n\x0f\x62\x61\x63kend_service\x18\x01 \x01(\t\x12\x0e\n\x06weight\x18\x02 \x01(\x01\x12\x89\x01\n\rheader_action\x18\x03 \x01(\x0b\x32r.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServicesXHeaderAction\"\xfc\x06\n0ComputeUrlMapXPathMatcherXRouteRulesXRouteAction\x12m\n\x0b\x63ors_policy\x18\x01 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXCorsPolicy\x12\x82\x01\n\x16\x66\x61ult_injection_policy\x18\x02 \x01(\x0b\x32\x62.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXFaultInjectionPolicy\x12\x80\x01\n\x15request_mirror_policy\x18\x03 \x01(\x0b\x32\x61.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRequestMirrorPolicy\x12o\n\x0cretry_policy\x18\x04 \x01(\x0b\x32Y.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXRetryPolicy\x12\x66\n\x07timeout\x18\x05 \x01(\x0b\x32U.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXTimeout\x12m\n\x0burl_rewrite\x18\x06 \x01(\x0b\x32X.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXUrlRewrite\x12\x88\x01\n\x19weighted_backend_services\x18\x07 \x03(\x0b\x32\x65.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteActionXWeightedBackendServices\"\xc6\x01\n0ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect\x12\x15\n\rhost_redirect\x18\x01 \x01(\t\x12\x16\n\x0ehttps_redirect\x18\x02 \x01(\x08\x12\x15\n\rpath_redirect\x18\x03 \x01(\t\x12\x17\n\x0fprefix_redirect\x18\x04 \x01(\t\x12\x1e\n\x16redirect_response_code\x18\x05 \x01(\t\x12\x13\n\x0bstrip_query\x18\x06 \x01(\x08\"\xdd\x03\n$ComputeUrlMapXPathMatcherXRouteRules\x12\x10\n\x08priority\x18\x01 \x01(\x01\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x65\n\rheader_action\x18\x03 \x01(\x0b\x32N.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXHeaderAction\x12\x61\n\x0bmatch_rules\x18\x04 \x03(\x0b\x32L.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXMatchRules\x12\x63\n\x0croute_action\x18\x05 \x01(\x0b\x32M.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXRouteAction\x12\x63\n\x0curl_redirect\x18\x06 \x01(\x0b\x32M.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRulesXUrlRedirect\"\xb1\x04\n\x19\x43omputeUrlMapXPathMatcher\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12g\n\x14\x64\x65\x66\x61ult_route_action\x18\x04 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultRouteAction\x12g\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x05 \x01(\x0b\x32I.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXDefaultUrlRedirect\x12Z\n\rheader_action\x18\x06 \x01(\x0b\x32\x43.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXHeaderAction\x12R\n\tpath_rule\x18\x07 \x03(\x0b\x32?.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXPathRule\x12V\n\x0broute_rules\x18\x08 \x03(\x0b\x32\x41.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcherXRouteRules\"V\n\x12\x43omputeUrlMapXTest\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"H\n\x16\x43omputeUrlMapXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x9b\x06\n\rComputeUrlMap\x12\x1a\n\x12\x63reation_timestamp\x18\x01 \x01(\t\x12\x17\n\x0f\x64\x65\x66\x61ult_service\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0e\n\x06map_id\x18\x06 \x01(\x01\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x11\n\tself_link\x18\t \x01(\t\x12[\n\x14\x64\x65\x66\x61ult_route_action\x18\n \x01(\x0b\x32=.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultRouteAction\x12[\n\x14\x64\x65\x66\x61ult_url_redirect\x18\x0b \x01(\x0b\x32=.oak9.tython.gcp.compute_url.ComputeUrlMapXDefaultUrlRedirect\x12N\n\rheader_action\x18\x0c \x01(\x0b\x32\x37.oak9.tython.gcp.compute_url.ComputeUrlMapXHeaderAction\x12\x46\n\thost_rule\x18\r \x03(\x0b\x32\x33.oak9.tython.gcp.compute_url.ComputeUrlMapXHostRule\x12L\n\x0cpath_matcher\x18\x0e \x03(\x0b\x32\x36.oak9.tython.gcp.compute_url.ComputeUrlMapXPathMatcher\x12=\n\x04test\x18\x0f \x03(\x0b\x32/.oak9.tython.gcp.compute_url.ComputeUrlMapXTest\x12\x45\n\x08timeouts\x18\x10 \x01(\x0b\x32\x33.oak9.tython.gcp.compute_url.ComputeUrlMapXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_url_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXCORSPOLICY._serialized_start=80
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXCORSPOLICY._serialized_end=310
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=312
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=414
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=416
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=520
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=523
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=726
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=729
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=994
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=996
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=1075
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=1077
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=1169
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_start=1172
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_end=1379
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXTIMEOUT._serialized_start=1381
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXTIMEOUT._serialized_end=1455
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXURLREWRITE._serialized_start=1457
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXURLREWRITE._serialized_end=1553
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=1556
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=1707
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=1710
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=1862
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=1865
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=2315
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=2318
  _COMPUTEURLMAPXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=2540
  _COMPUTEURLMAPXDEFAULTROUTEACTION._serialized_start=2543
  _COMPUTEURLMAPXDEFAULTROUTEACTION._serialized_end=3304
  _COMPUTEURLMAPXDEFAULTURLREDIRECT._serialized_start=3307
  _COMPUTEURLMAPXDEFAULTURLREDIRECT._serialized_end=3489
  _COMPUTEURLMAPXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=3491
  _COMPUTEURLMAPXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=3599
  _COMPUTEURLMAPXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=3601
  _COMPUTEURLMAPXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=3710
  _COMPUTEURLMAPXHEADERACTION._serialized_start=3713
  _COMPUTEURLMAPXHEADERACTION._serialized_end=4032
  _COMPUTEURLMAPXHOSTRULE._serialized_start=4034
  _COMPUTEURLMAPXHOSTRULE._serialized_end=4116
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXCORSPOLICY._serialized_start=4119
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXCORSPOLICY._serialized_end=4361
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=4363
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=4477
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=4479
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=4595
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=4598
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=4826
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=4829
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=5130
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=5132
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=5223
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=5225
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=5329
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_start=5332
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXRETRYPOLICY._serialized_end=5563
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXTIMEOUT._serialized_start=5565
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXTIMEOUT._serialized_end=5651
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXURLREWRITE._serialized_start=5653
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXURLREWRITE._serialized_end=5761
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=5764
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=5927
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=5930
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=6094
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=6097
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=6585
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=6588
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=6835
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTION._serialized_start=6838
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTROUTEACTION._serialized_end=7696
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_start=7699
  _COMPUTEURLMAPXPATHMATCHERXDEFAULTURLREDIRECT._serialized_end=7893
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=7895
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=8015
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=8017
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=8138
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTION._serialized_start=8141
  _COMPUTEURLMAPXPATHMATCHERXHEADERACTION._serialized_end=8496
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_start=8499
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXCORSPOLICY._serialized_end=8743
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=8745
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=8861
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=8863
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=8981
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=8984
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=9216
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=9219
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=9526
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=9528
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=9621
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=9623
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=9729
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_start=9732
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXRETRYPOLICY._serialized_end=9967
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_start=9969
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXTIMEOUT._serialized_end=10057
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_start=10059
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXURLREWRITE._serialized_end=10169
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=10172
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=10337
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=10340
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=10506
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=10509
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=11003
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=11006
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=11257
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_start=11260
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXROUTEACTION._serialized_end=12135
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_start=12138
  _COMPUTEURLMAPXPATHMATCHERXPATHRULEXURLREDIRECT._serialized_end=12334
  _COMPUTEURLMAPXPATHMATCHERXPATHRULE._serialized_start=12337
  _COMPUTEURLMAPXPATHMATCHERXPATHRULE._serialized_end=12603
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=12606
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=12737
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=12740
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=12872
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_start=12875
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXHEADERACTION._serialized_end=13265
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_start=13267
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHESXRANGEMATCH._serialized_end=13381
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_start=13384
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXHEADERMATCHES._serialized_end=13723
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_start=13725
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERSXFILTERLABELS._serialized_end=13832
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_start=13835
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXMETADATAFILTERS._serialized_end=14062
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_start=14065
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULESXQUERYPARAMETERMATCHES._serialized_end=14215
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_start=14218
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXMATCHRULES._serialized_end=14726
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_start=14729
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXCORSPOLICY._serialized_end=14975
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_start=14977
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXABORT._serialized_end=15095
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_start=15097
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAYXFIXEDDELAY._serialized_end=15217
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_start=15220
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICYXDELAY._serialized_end=15456
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_start=15459
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXFAULTINJECTIONPOLICY._serialized_end=15772
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_start=15774
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXREQUESTMIRRORPOLICY._serialized_end=15869
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_start=15871
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICYXPERTRYTIMEOUT._serialized_end=15979
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_start=15982
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXRETRYPOLICY._serialized_end=16222
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_start=16224
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXTIMEOUT._serialized_end=16314
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_start=16316
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXURLREWRITE._serialized_end=16428
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_start=16431
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXREQUESTHEADERSTOADD._serialized_end=16598
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_start=16601
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTIONXRESPONSEHEADERSTOADD._serialized_end=16769
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_start=16772
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICESXHEADERACTION._serialized_end=17272
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_start=17275
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTIONXWEIGHTEDBACKENDSERVICES._serialized_end=17530
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_start=17533
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXROUTEACTION._serialized_end=18425
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_start=18428
  _COMPUTEURLMAPXPATHMATCHERXROUTERULESXURLREDIRECT._serialized_end=18626
  _COMPUTEURLMAPXPATHMATCHERXROUTERULES._serialized_start=18629
  _COMPUTEURLMAPXPATHMATCHERXROUTERULES._serialized_end=19106
  _COMPUTEURLMAPXPATHMATCHER._serialized_start=19109
  _COMPUTEURLMAPXPATHMATCHER._serialized_end=19670
  _COMPUTEURLMAPXTEST._serialized_start=19672
  _COMPUTEURLMAPXTEST._serialized_end=19758
  _COMPUTEURLMAPXTIMEOUTS._serialized_start=19760
  _COMPUTEURLMAPXTIMEOUTS._serialized_end=19832
  _COMPUTEURLMAP._serialized_start=19835
  _COMPUTEURLMAP._serialized_end=20630
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_memcache.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_memcache.proto\x12\x18oak9.tython.gcp.memcache\x1a\x13shared/shared.proto\"\x86\x01\nDMemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"\xcf\x01\n:MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\t\x12\x10\n\x08\x64uration\x18\x02 \x01(\t\x12r\n\nstart_time\x18\x03 \x01(\x0b\x32^.oak9.tython.gcp.memcache.MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindowXStartTime\"\xdc\x01\n\"MemcacheInstanceXMaintenancePolicy\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x13\n\x0bupdate_time\x18\x03 \x01(\t\x12w\n\x19weekly_maintenance_window\x18\x04 \x03(\x0b\x32T.oak9.tython.gcp.memcache.MemcacheInstanceXMaintenancePolicyXWeeklyMaintenanceWindow\"\xbb\x01\n#MemcacheInstanceXMemcacheParameters\x12\n\n\x02id\x18\x01 \x01(\t\x12Y\n\x06params\x18\x02 \x03(\x0b\x32I.oak9.tython.gcp.memcache.MemcacheInstanceXMemcacheParameters.ParamsEntry\x1a-\n\x0bParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x1bMemcacheInstanceXNodeConfig\x12\x11\n\tcpu_count\x18\x01 \x01(\x01\x12\x16\n\x0ememory_size_mb\x18\x02 \x01(\x01\"K\n\x19MemcacheInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb1\x08\n\x10MemcacheInstance\x12\x1a\n\x12\x61uthorized_network\x18\x01 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x02 \x01(\t\x12\x1a\n\x12\x64iscovery_endpoint\x18\x03 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x06labels\x18\x06 \x03(\x0b\x32\x36.oak9.tython.gcp.memcache.MemcacheInstance.LabelsEntry\x12\x61\n\x14maintenance_schedule\x18\x07 \x03(\x0b\x32\x43.oak9.tython.gcp.memcache.MemcacheInstance.MaintenanceScheduleEntry\x12\x1d\n\x15memcache_full_version\x18\x08 \x01(\t\x12U\n\x0ememcache_nodes\x18\t \x03(\x0b\x32=.oak9.tython.gcp.memcache.MemcacheInstance.MemcacheNodesEntry\x12\x18\n\x10memcache_version\x18\n \x01(\t\x12\x0c\n\x04name\x18\x0b \x01(\t\x12\x12\n\nnode_count\x18\x0c \x01(\x01\x12\x0f\n\x07project\x18\r \x01(\t\x12\x0e\n\x06region\x18\x0e \x01(\t\x12\r\n\x05zones\x18\x0f \x03(\t\x12X\n\x12maintenance_policy\x18\x10 \x01(\x0b\x32<.oak9.tython.gcp.memcache.MemcacheInstanceXMaintenancePolicy\x12Z\n\x13memcache_parameters\x18\x11 \x01(\x0b\x32=.oak9.tython.gcp.memcache.MemcacheInstanceXMemcacheParameters\x12J\n\x0bnode_config\x18\x12 \x01(\x0b\x32\x35.oak9.tython.gcp.memcache.MemcacheInstanceXNodeConfig\x12\x45\n\x08timeouts\x18\x13 \x01(\x0b\x32\x33.oak9.tython.gcp.memcache.MemcacheInstanceXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a:\n\x18MaintenanceScheduleEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x34\n\x12MemcacheNodesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_memcache_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS_PARAMSENTRY._options = None
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS_PARAMSENTRY._serialized_options = b'8\001'
  _MEMCACHEINSTANCE_LABELSENTRY._options = None
  _MEMCACHEINSTANCE_LABELSENTRY._serialized_options = b'8\001'
  _MEMCACHEINSTANCE_MAINTENANCESCHEDULEENTRY._options = None
  _MEMCACHEINSTANCE_MAINTENANCESCHEDULEENTRY._serialized_options = b'8\001'
  _MEMCACHEINSTANCE_MEMCACHENODESENTRY._options = None
  _MEMCACHEINSTANCE_MEMCACHENODESENTRY._serialized_options = b'8\001'
  _MEMCACHEINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_start=74
  _MEMCACHEINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOWXSTARTTIME._serialized_end=208
  _MEMCACHEINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_start=211
  _MEMCACHEINSTANCEXMAINTENANCEPOLICYXWEEKLYMAINTENANCEWINDOW._serialized_end=418
  _MEMCACHEINSTANCEXMAINTENANCEPOLICY._serialized_start=421
  _MEMCACHEINSTANCEXMAINTENANCEPOLICY._serialized_end=641
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS._serialized_start=644
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS._serialized_end=831
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS_PARAMSENTRY._serialized_start=786
  _MEMCACHEINSTANCEXMEMCACHEPARAMETERS_PARAMSENTRY._serialized_end=831
  _MEMCACHEINSTANCEXNODECONFIG._serialized_start=833
  _MEMCACHEINSTANCEXNODECONFIG._serialized_end=905
  _MEMCACHEINSTANCEXTIMEOUTS._serialized_start=907
  _MEMCACHEINSTANCEXTIMEOUTS._serialized_end=982
  _MEMCACHEINSTANCE._serialized_start=985
  _MEMCACHEINSTANCE._serialized_end=2058
  _MEMCACHEINSTANCE_LABELSENTRY._serialized_start=1899
  _MEMCACHEINSTANCE_LABELSENTRY._serialized_end=1944
  _MEMCACHEINSTANCE_MAINTENANCESCHEDULEENTRY._serialized_start=1946
  _MEMCACHEINSTANCE_MAINTENANCESCHEDULEENTRY._serialized_end=2004
  _MEMCACHEINSTANCE_MEMCACHENODESENTRY._serialized_start=2006
  _MEMCACHEINSTANCE_MEMCACHENODESENTRY._serialized_end=2058
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHealthCheckXGrpcHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    GRPC_SERVICE_NAME_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    grpc_service_name: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    def __init__(
        self,
        *,
        grpc_service_name: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["grpc_service_name", b"grpc_service_name", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification"]) -> None: ...

global___ComputeHealthCheckXGrpcHealthCheck = ComputeHealthCheckXGrpcHealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttp2HealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttp2HealthCheck = ComputeHealthCheckXHttp2HealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttpHealthCheck = ComputeHealthCheckXHttpHealthCheck

@typing_extensions.final
class ComputeHealthCheckXHttpsHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    HOST_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_PATH_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    host: builtins.str
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request_path: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        host: builtins.str = ...,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request_path: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["host", b"host", "port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request_path", b"request_path", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXHttpsHealthCheck = ComputeHealthCheckXHttpsHealthCheck

@typing_extensions.final
class ComputeHealthCheckXLogConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ENABLE_FIELD_NUMBER: builtins.int
    enable: builtins.bool
    def __init__(
        self,
        *,
        enable: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["enable", b"enable"]) -> None: ...

global___ComputeHealthCheckXLogConfig = ComputeHealthCheckXLogConfig

@typing_extensions.final
class ComputeHealthCheckXSslHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXSslHealthCheck = ComputeHealthCheckXSslHealthCheck

@typing_extensions.final
class ComputeHealthCheckXTcpHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORT_FIELD_NUMBER: builtins.int
    PORT_NAME_FIELD_NUMBER: builtins.int
    PORT_SPECIFICATION_FIELD_NUMBER: builtins.int
    PROXY_HEADER_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    RESPONSE_FIELD_NUMBER: builtins.int
    port: builtins.float
    port_name: builtins.str
    port_specification: builtins.str
    proxy_header: builtins.str
    request: builtins.str
    response: builtins.str
    def __init__(
        self,
        *,
        port: builtins.float = ...,
        port_name: builtins.str = ...,
        port_specification: builtins.str = ...,
        proxy_header: builtins.str = ...,
        request: builtins.str = ...,
        response: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["port", b"port", "port_name", b"port_name", "port_specification", b"port_specification", "proxy_header", b"proxy_header", "request", b"request", "response", b"response"]) -> None: ...

global___ComputeHealthCheckXTcpHealthCheck = ComputeHealthCheckXTcpHealthCheck

@typing_extensions.final
class ComputeHealthCheckXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeHealthCheckXTimeouts = ComputeHealthCheckXTimeouts

@typing_extensions.final
class ComputeHealthCheck(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CHECK_INTERVAL_SEC_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    HEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUT_SEC_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UNHEALTHY_THRESHOLD_FIELD_NUMBER: builtins.int
    GRPC_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP2_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    HTTPS_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    LOG_CONFIG_FIELD_NUMBER: builtins.int
    SSL_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TCP_HEALTH_CHECK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    check_interval_sec: builtins.float
    creation_timestamp: builtins.str
    description: builtins.str
    healthy_threshold: builtins.float
    id: builtins.str
    name: builtins.str
    project: builtins.str
    self_link: builtins.str
    timeout_sec: builtins.float
    type: builtins.str
    unhealthy_threshold: builtins.float
    @property
    def grpc_health_check(self) -> global___ComputeHealthCheckXGrpcHealthCheck: ...
    @property
    def http2_health_check(self) -> global___ComputeHealthCheckXHttp2HealthCheck: ...
    @property
    def http_health_check(self) -> global___ComputeHealthCheckXHttpHealthCheck: ...
    @property
    def https_health_check(self) -> global___ComputeHealthCheckXHttpsHealthCheck: ...
    @property
    def log_config(self) -> global___ComputeHealthCheckXLogConfig: ...
    @property
    def ssl_health_check(self) -> global___ComputeHealthCheckXSslHealthCheck: ...
    @property
    def tcp_health_check(self) -> global___ComputeHealthCheckXTcpHealthCheck: ...
    @property
    def timeouts(self) -> global___ComputeHealthCheckXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        check_interval_sec: builtins.float = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        healthy_threshold: builtins.float = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        timeout_sec: builtins.float = ...,
        type: builtins.str = ...,
        unhealthy_threshold: builtins.float = ...,
        grpc_health_check: global___ComputeHealthCheckXGrpcHealthCheck | None = ...,
        http2_health_check: global___ComputeHealthCheckXHttp2HealthCheck | None = ...,
        http_health_check: global___ComputeHealthCheckXHttpHealthCheck | None = ...,
        https_health_check: global___ComputeHealthCheckXHttpsHealthCheck | None = ...,
        log_config: global___ComputeHealthCheckXLogConfig | None = ...,
        ssl_health_check: global___ComputeHealthCheckXSslHealthCheck | None = ...,
        tcp_health_check: global___ComputeHealthCheckXTcpHealthCheck | None = ...,
        timeouts: global___ComputeHealthCheckXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["grpc_health_check", b"grpc_health_check", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "log_config", b"log_config", "resource_info", b"resource_info", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["check_interval_sec", b"check_interval_sec", "creation_timestamp", b"creation_timestamp", "description", b"description", "grpc_health_check", b"grpc_health_check", "healthy_threshold", b"healthy_threshold", "http2_health_check", b"http2_health_check", "http_health_check", b"http_health_check", "https_health_check", b"https_health_check", "id", b"id", "log_config", b"log_config", "name", b"name", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "ssl_health_check", b"ssl_health_check", "tcp_health_check", b"tcp_health_check", "timeout_sec", b"timeout_sec", "timeouts", b"timeouts", "type", b"type", "unhealthy_threshold", b"unhealthy_threshold"]) -> None: ...

global___ComputeHealthCheck = ComputeHealthCheck



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Keyspace(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEYSPACE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    keyspace_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        keyspace_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyspace_name", b"keyspace_name", "resource_info", b"resource_info"]) -> None: ...

global___Keyspace = Keyspace

@typing_extensions.final
class Cassandra(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYSPACE_FIELD_NUMBER: builtins.int
    TABLE_FIELD_NUMBER: builtins.int
    @property
    def keyspace(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Keyspace]: ...
    @property
    def table(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Table]: ...
    def __init__(
        self,
        *,
        keyspace: collections.abc.Iterable[global___Keyspace] | None = ...,
        table: collections.abc.Iterable[global___Table] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyspace", b"keyspace", "table", b"table"]) -> None: ...

global___Cassandra = Cassandra

@typing_extensions.final
class TableColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COLUMN_NAME_FIELD_NUMBER: builtins.int
    COLUMN_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    column_name: builtins.str
    column_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        column_name: builtins.str = ...,
        column_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column_name", b"column_name", "column_type", b"column_type", "resource_info", b"resource_info"]) -> None: ...

global___TableColumn = TableColumn

@typing_extensions.final
class TableClusteringKeyColumn(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    COLUMN_FIELD_NUMBER: builtins.int
    ORDER_BY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def column(self) -> global___TableColumn: ...
    order_by: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        column: global___TableColumn | None = ...,
        order_by: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["column", b"column", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["column", b"column", "order_by", b"order_by", "resource_info", b"resource_info"]) -> None: ...

global___TableClusteringKeyColumn = TableClusteringKeyColumn

@typing_extensions.final
class TableProvisionedThroughput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    READ_CAPACITY_UNITS_FIELD_NUMBER: builtins.int
    WRITE_CAPACITY_UNITS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    read_capacity_units: builtins.int
    write_capacity_units: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        read_capacity_units: builtins.int = ...,
        write_capacity_units: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["read_capacity_units", b"read_capacity_units", "resource_info", b"resource_info", "write_capacity_units", b"write_capacity_units"]) -> None: ...

global___TableProvisionedThroughput = TableProvisionedThroughput

@typing_extensions.final
class TableBillingMode(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    PROVISIONED_THROUGHPUT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    mode: builtins.str
    @property
    def provisioned_throughput(self) -> global___TableProvisionedThroughput: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        mode: builtins.str = ...,
        provisioned_throughput: global___TableProvisionedThroughput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provisioned_throughput", b"provisioned_throughput", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["mode", b"mode", "provisioned_throughput", b"provisioned_throughput", "resource_info", b"resource_info"]) -> None: ...

global___TableBillingMode = TableBillingMode

@typing_extensions.final
class Table(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEYSPACE_NAME_FIELD_NUMBER: builtins.int
    TABLE_NAME_FIELD_NUMBER: builtins.int
    REGULAR_COLUMNS_FIELD_NUMBER: builtins.int
    PARTITION_KEY_COLUMNS_FIELD_NUMBER: builtins.int
    CLUSTERING_KEY_COLUMNS_FIELD_NUMBER: builtins.int
    BILLING_MODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    keyspace_name: builtins.str
    table_name: builtins.str
    @property
    def regular_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableColumn]: ...
    @property
    def partition_key_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableColumn]: ...
    @property
    def clustering_key_columns(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TableClusteringKeyColumn]: ...
    @property
    def billing_mode(self) -> global___TableBillingMode: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        keyspace_name: builtins.str = ...,
        table_name: builtins.str = ...,
        regular_columns: collections.abc.Iterable[global___TableColumn] | None = ...,
        partition_key_columns: collections.abc.Iterable[global___TableColumn] | None = ...,
        clustering_key_columns: collections.abc.Iterable[global___TableClusteringKeyColumn] | None = ...,
        billing_mode: global___TableBillingMode | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["billing_mode", b"billing_mode", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["billing_mode", b"billing_mode", "clustering_key_columns", b"clustering_key_columns", "keyspace_name", b"keyspace_name", "partition_key_columns", b"partition_key_columns", "regular_columns", b"regular_columns", "resource_info", b"resource_info", "table_name", b"table_name"]) -> None: ...

global___Table = Table



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApplicationMaxAgeRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELETE_SOURCE_FROM_S3_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    MAX_AGE_IN_DAYS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delete_source_from_s3: builtins.bool
    enabled: builtins.bool
    max_age_in_days: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delete_source_from_s3: builtins.bool = ...,
        enabled: builtins.bool = ...,
        max_age_in_days: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_source_from_s3", b"delete_source_from_s3", "enabled", b"enabled", "max_age_in_days", b"max_age_in_days", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationMaxAgeRule = ApplicationMaxAgeRule

@typing_extensions.final
class ApplicationMaxCountRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DELETE_SOURCE_FROM_S3_FIELD_NUMBER: builtins.int
    ENABLED_FIELD_NUMBER: builtins.int
    MAX_COUNT_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    delete_source_from_s3: builtins.bool
    enabled: builtins.bool
    max_count: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        delete_source_from_s3: builtins.bool = ...,
        enabled: builtins.bool = ...,
        max_count: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["delete_source_from_s3", b"delete_source_from_s3", "enabled", b"enabled", "max_count", b"max_count", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationMaxCountRule = ApplicationMaxCountRule

@typing_extensions.final
class ApplicationApplicationVersionLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MAX_AGE_RULE_FIELD_NUMBER: builtins.int
    MAX_COUNT_RULE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def max_age_rule(self) -> global___ApplicationMaxAgeRule: ...
    @property
    def max_count_rule(self) -> global___ApplicationMaxCountRule: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        max_age_rule: global___ApplicationMaxAgeRule | None = ...,
        max_count_rule: global___ApplicationMaxCountRule | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_age_rule", b"max_age_rule", "max_count_rule", b"max_count_rule", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_age_rule", b"max_age_rule", "max_count_rule", b"max_count_rule", "resource_info", b"resource_info"]) -> None: ...

global___ApplicationApplicationVersionLifecycleConfig = ApplicationApplicationVersionLifecycleConfig

@typing_extensions.final
class ApplicationApplicationResourceLifecycleConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVICE_ROLE_FIELD_NUMBER: builtins.int
    VERSION_LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    service_role: builtins.str
    @property
    def version_lifecycle_config(self) -> global___ApplicationApplicationVersionLifecycleConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        service_role: builtins.str = ...,
        version_lifecycle_config: global___ApplicationApplicationVersionLifecycleConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "version_lifecycle_config", b"version_lifecycle_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service_role", b"service_role", "version_lifecycle_config", b"version_lifecycle_config"]) -> None: ...

global___ApplicationApplicationResourceLifecycleConfig = ApplicationApplicationResourceLifecycleConfig

@typing_extensions.final
class Application(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    RESOURCE_LIFECYCLE_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    description: builtins.str
    @property
    def resource_lifecycle_config(self) -> global___ApplicationApplicationResourceLifecycleConfig: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        description: builtins.str = ...,
        resource_lifecycle_config: global___ApplicationApplicationResourceLifecycleConfig | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "resource_lifecycle_config", b"resource_lifecycle_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "description", b"description", "resource_info", b"resource_info", "resource_lifecycle_config", b"resource_lifecycle_config"]) -> None: ...

global___Application = Application

@typing_extensions.final
class ElasticBeanstalk(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    APPLICATION_FIELD_NUMBER: builtins.int
    APPLICATION_VERSION_FIELD_NUMBER: builtins.int
    CONFIGURATION_TEMPLATE_FIELD_NUMBER: builtins.int
    ENVIRONMENT_FIELD_NUMBER: builtins.int
    @property
    def application(self) -> global___Application: ...
    @property
    def application_version(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApplicationVersion]: ...
    @property
    def configuration_template(self) -> global___ConfigurationTemplate: ...
    @property
    def environment(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Environment]: ...
    def __init__(
        self,
        *,
        application: global___Application | None = ...,
        application_version: collections.abc.Iterable[global___ApplicationVersion] | None = ...,
        configuration_template: global___ConfigurationTemplate | None = ...,
        environment: collections.abc.Iterable[global___Environment] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["application", b"application", "configuration_template", b"configuration_template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application", b"application", "application_version", b"application_version", "configuration_template", b"configuration_template", "environment", b"environment"]) -> None: ...

global___ElasticBeanstalk = ElasticBeanstalk

@typing_extensions.final
class ApplicationVersionSourceBundle(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    S3_BUCKET_FIELD_NUMBER: builtins.int
    S3_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    s3_bucket: builtins.str
    s3_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        s3_bucket: builtins.str = ...,
        s3_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "s3_bucket", b"s3_bucket", "s3_key", b"s3_key"]) -> None: ...

global___ApplicationVersionSourceBundle = ApplicationVersionSourceBundle

@typing_extensions.final
class ApplicationVersion(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SOURCE_BUNDLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    description: builtins.str
    @property
    def source_bundle(self) -> global___ApplicationVersionSourceBundle: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        description: builtins.str = ...,
        source_bundle: global___ApplicationVersionSourceBundle | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_bundle", b"source_bundle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "description", b"description", "resource_info", b"resource_info", "source_bundle", b"source_bundle"]) -> None: ...

global___ApplicationVersion = ApplicationVersion

@typing_extensions.final
class ConfigurationTemplateConfigurationOptionSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OPTION_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    namespace: builtins.str
    option_name: builtins.str
    resource_name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        namespace: builtins.str = ...,
        option_name: builtins.str = ...,
        resource_name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace", b"namespace", "option_name", b"option_name", "resource_info", b"resource_info", "resource_name", b"resource_name", "value", b"value"]) -> None: ...

global___ConfigurationTemplateConfigurationOptionSetting = ConfigurationTemplateConfigurationOptionSetting

@typing_extensions.final
class ConfigurationTemplateSourceConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    template_name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        template_name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "resource_info", b"resource_info", "template_name", b"template_name"]) -> None: ...

global___ConfigurationTemplateSourceConfiguration = ConfigurationTemplateSourceConfiguration

@typing_extensions.final
class ConfigurationTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_ID_FIELD_NUMBER: builtins.int
    OPTION_SETTINGS_FIELD_NUMBER: builtins.int
    PLATFORM_ARN_FIELD_NUMBER: builtins.int
    SOLUTION_STACK_NAME_FIELD_NUMBER: builtins.int
    SOURCE_CONFIGURATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    description: builtins.str
    environment_id: builtins.str
    @property
    def option_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ConfigurationTemplateConfigurationOptionSetting]: ...
    platform_arn: builtins.str
    solution_stack_name: builtins.str
    @property
    def source_configuration(self) -> global___ConfigurationTemplateSourceConfiguration: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        description: builtins.str = ...,
        environment_id: builtins.str = ...,
        option_settings: collections.abc.Iterable[global___ConfigurationTemplateConfigurationOptionSetting] | None = ...,
        platform_arn: builtins.str = ...,
        solution_stack_name: builtins.str = ...,
        source_configuration: global___ConfigurationTemplateSourceConfiguration | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "source_configuration", b"source_configuration"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "description", b"description", "environment_id", b"environment_id", "option_settings", b"option_settings", "platform_arn", b"platform_arn", "resource_info", b"resource_info", "solution_stack_name", b"solution_stack_name", "source_configuration", b"source_configuration"]) -> None: ...

global___ConfigurationTemplate = ConfigurationTemplate

@typing_extensions.final
class EnvironmentOptionSetting(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    OPTION_NAME_FIELD_NUMBER: builtins.int
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    namespace: builtins.str
    option_name: builtins.str
    resource_name: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        namespace: builtins.str = ...,
        option_name: builtins.str = ...,
        resource_name: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["namespace", b"namespace", "option_name", b"option_name", "resource_info", b"resource_info", "resource_name", b"resource_name", "value", b"value"]) -> None: ...

global___EnvironmentOptionSetting = EnvironmentOptionSetting

@typing_extensions.final
class EnvironmentTier(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    version: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___EnvironmentTier = EnvironmentTier

@typing_extensions.final
class Environment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    APPLICATION_NAME_FIELD_NUMBER: builtins.int
    CNAME_PREFIX_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ENVIRONMENT_NAME_FIELD_NUMBER: builtins.int
    OPTION_SETTINGS_FIELD_NUMBER: builtins.int
    PLATFORM_ARN_FIELD_NUMBER: builtins.int
    SOLUTION_STACK_NAME_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TEMPLATE_NAME_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    VERSION_LABEL_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    application_name: builtins.str
    cname_prefix: builtins.str
    description: builtins.str
    environment_name: builtins.str
    @property
    def option_settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___EnvironmentOptionSetting]: ...
    platform_arn: builtins.str
    solution_stack_name: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    template_name: builtins.str
    @property
    def tier(self) -> global___EnvironmentTier: ...
    version_label: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        application_name: builtins.str = ...,
        cname_prefix: builtins.str = ...,
        description: builtins.str = ...,
        environment_name: builtins.str = ...,
        option_settings: collections.abc.Iterable[global___EnvironmentOptionSetting] | None = ...,
        platform_arn: builtins.str = ...,
        solution_stack_name: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        template_name: builtins.str = ...,
        tier: global___EnvironmentTier | None = ...,
        version_label: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tier", b"tier"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["application_name", b"application_name", "cname_prefix", b"cname_prefix", "description", b"description", "environment_name", b"environment_name", "option_settings", b"option_settings", "platform_arn", b"platform_arn", "resource_info", b"resource_info", "solution_stack_name", b"solution_stack_name", "tags", b"tags", "template_name", b"template_name", "tier", b"tier", "version_label", b"version_label"]) -> None: ...

global___Environment = Environment
